@@ -253,7 +253,7 @@ sub dbdrivers {
 
   my @drivers = DBI->available_drivers();
 
-  return (grep { /(Sybase|Pg)/ } @drivers);
+  return (grep { /(Sybase|Pg|Oracle)/ } @drivers);
 
 }
 
@@ -811,8 +811,8 @@ sub config_vars {
   my @conf = qw(acs company countrycode dateformat
              dbconnect dbdriver dbhost dbname dboptions dbpasswd
 	     dbport dbuser menuwidth name email numberformat password
-	     outputformat pin printer sessionkey sid
-	     signature stylesheet timeout vclimit);
+	     outputformat printer sessionkey sid
+	     signature stylesheet tan timeout vclimit);
 
   @conf;
 
