@@ -55,14 +55,17 @@ sub add {
   
   if ($form->{batch}) {
     $form->{title} = $locale->text('Add General Ledger Voucher');
+    $form->helpref("gl_voucher", $myconfig{countrycode});
     if ($form->{batchdescription}) {
       $form->{title} .= " / $form->{batchdescription}";
     }
   } else {
     if ($form->{fxadj}) {
       $form->{title} = $locale->text('Add FX Adjustment');
+      $form->helpref("fx_adjustment", $myconfig{countrycode});
     } else {
       $form->{title} = $locale->text('Add General Ledger Transaction');
+      $form->helpref("gl_transaction", $myconfig{countrycode});
     }
   }
   
@@ -74,14 +77,12 @@ sub add {
 
   $form->{transdate} = $transdate if $transdate;
 
-  $form->{rowcount} = ($form->{fxadj}) ? 2 : 9;
+  $form->{rowcount} = ($form->{fxadj}) ? 3 : 9;
   $form->{oldtransdate} = $form->{transdate};
   $form->{focus} = "reference";
 
   $form->{currency} = $form->{defaultcurrency};
 
-#  delete $form->{defaultcurrency} if $form->{fxadj};
-
   &display_form(1);
   
 }
@@ -93,18 +94,19 @@ sub edit {
  
   $form->{locked} = ($form->{revtrans}) ? '1' : ($form->datetonum(\%myconfig, $form->{transdate}) <= $form->{closedto});
 
-#  delete $form->{defaultcurrency} if $form->{fxadj};
-
   if ($form->{batch}) {
     $form->{title} = $locale->text('Edit General Ledger Voucher');
+    $form->helpref("gl_voucher", $myconfig{countrycode});
     if ($form->{batchdescription}) {
       $form->{title} .= " / $form->{batchdescription}";
     }
   } else {
     if ($form->{fxadj}) {
       $form->{title} = $locale->text('Edit FX Adjustment');
+      $form->helpref("fx_adjustment", $myconfig{countrycode});
     } else {
       $form->{title} = $locale->text('Edit General Ledger Transaction');
+      $form->helpref("gl_transaction", $myconfig{countrycode});
     }
   }
  
@@ -167,6 +169,7 @@ sub create_links {
   # projects
   if (@{ $form->{all_project} }) {
     $form->{selectprojectnumber} = "\n";
+    $form->{projectnumber} ||= "";
     for (@{ $form->{all_project} }) { $form->{selectprojectnumber} .= qq|$_->{projectnumber}--$_->{id}\n| }
   }
 
@@ -177,6 +180,15 @@ sub create_links {
     for (@{ $form->{all_department} }) { $form->{selectdepartment} .= qq|$_->{description}--$_->{id}\n| }
   }
 
+  # reference
+  $i = 0;
+  for (@{ $form->{all_reference} }) {
+    $i++;
+    $form->{"referencedescription_$i"} = $_->{description};
+    $form->{"referenceid_$i"} = $_->{id};
+  }
+  $form->{reference_rows} = $i;
+
   for (qw(department projectnumber accno currency)) { $form->{"select$_"} = $form->escape($form->{"select$_"},1) }
   
 }
@@ -185,36 +197,43 @@ sub create_links {
 sub search {
 
   $form->{title} = $locale->text('General Ledger')." ".$locale->text('Reports');
+
+  $form->{reportcode} = 'gl';
+  $form->{dateformat} = $myconfig{dateformat};
   
   $form->all_departments(\%myconfig);
+
   # departments
   if (@{ $form->{all_department} }) {
-    $selectdepartment = "<option>\n";
-    for (@{ $form->{all_department} }) { $selectdepartment .= qq|<option value="|.$form->quote($_->{description}).qq|--$_->{id}">$_->{description}\n| }
+    $form->{selectdepartment} = "\n";
+    for (@{ $form->{all_department} }) { $form->{selectdepartment} .= qq|$_->{description}--$_->{id}\n| }
 
-    @l_department = (qq|<input name="l_department" class=checkbox type=checkbox value=Y>|, $locale->text('Department'));
+    $l_department = 1;
 
     $department = qq|
   	<tr>
 	  <th align=right>|.$locale->text('Department').qq|</th>
-	  <td><select name=department>$selectdepartment</select></td>
+	  <td><select name=department>|
+	  .$form->select_option($form->{selectdepartment}, $form->{department}, 1)
+	  .qq|
+	  </select></td>
 	</tr>
 |;
   }
 
   if (@{ $form->{all_years} }) {
     # accounting years
-    $selectaccountingyear = "<option>\n";
-    for (@{ $form->{all_years} }) { $selectaccountingyear .= qq|<option>$_\n| }
-    $selectaccountingmonth = "<option>\n";
-    for (sort keys %{ $form->{all_month} }) { $selectaccountingmonth .= qq|<option value=$_>|.$locale->text($form->{all_month}{$_}).qq|\n| }
+    $selectaccountingyear = "\n";
+    for (@{ $form->{all_years} }) { $selectaccountingyear .= qq|$_\n| }
+    $selectaccountingmonth = "\n";
+    for (sort keys %{ $form->{all_month} }) { $selectaccountingmonth .= qq|$_--|.$locale->text($form->{all_month}{$_}).qq|\n| }
 
     $selectfrom = qq|
         <tr>
 	<th align=right>|.$locale->text('Period').qq|</th>
 	<td>
-	<select name=month>$selectaccountingmonth</select>
-	<select name=year>$selectaccountingyear</select>
+	<select name=month>|.$form->select_option($selectaccountingmonth, $form->{month}, 1, 1).qq|</select>
+	<select name=year>|.$form->select_option($selectaccountingyear, $form->{year}).qq|</select>
 	<input name=interval class=radio type=radio value=0 checked>&nbsp;|.$locale->text('Current').qq|
 	<input name=interval class=radio type=radio value=1>&nbsp;|.$locale->text('Month').qq|
 	<input name=interval class=radio type=radio value=3>&nbsp;|.$locale->text('Quarter').qq|
@@ -224,42 +243,83 @@ sub search {
 |;
   }
 
-  @a = ();
-  push @a, (qq|<input name="l_id" class=checkbox type=checkbox value=Y>|, $locale->text('ID'));
-  push @a, (qq|<input name="l_transdate" class=checkbox type=checkbox value=Y checked>|, $locale->text('Date'));
-  push @a, (qq|<input name="l_reference" class=checkbox type=checkbox value=Y checked>|, $locale->text('Reference'));
-  push @a, (qq|<input name="l_description" class=checkbox type=checkbox value=Y checked>|, $locale->text('Description'));
-  push @a, (qq|<input name="l_name" class=checkbox type=checkbox value=Y checked>|, $locale->text('Company Name'));
-  push @a, (qq|<input name="l_vcnumber" class=checkbox type=checkbox value=Y>|, $locale->text('Company Number'));
-  push @a, (qq|<input name="l_address" class=checkbox type=checkbox value=Y>|, $locale->text('Address'));
-  push @a, @l_department if @l_department;
-  push @a, (qq|<input name="l_notes" class=checkbox type=checkbox value=Y>|, $locale->text('Notes'));
-  push @a, (qq|<input name="l_debit" class=checkbox type=checkbox value=Y checked>|, $locale->text('Debit'));
-  push @a, (qq|<input name="l_credit" class=checkbox type=checkbox value=Y checked>|, $locale->text('Credit'));
-  push @a, (qq|<input name="l_source" class=checkbox type=checkbox value=Y checked>|, $locale->text('Source'));
-  push @a, (qq|<input name="l_memo" class=checkbox type=checkbox value=Y>|, $locale->text('Memo'));
-  push @a, (qq|<input name="l_lineitem" class=checkbox type=checkbox value=Y>|, $locale->text('Line Item'));
-  push @a, (qq|<input name="l_accno" class=checkbox type=checkbox value=Y checked>|, $locale->text('Account'));
-  push @a, (qq|<input name="l_gifi_accno" class=checkbox type=checkbox value=Y>|, $locale->text('GIFI'));
+  if (@{ $form->{all_report} }) {
+    $form->{selectreportform} = "\n";
+    for (@{ $form->{all_report} }) { $form->{selectreportform} .= qq|$_->{reportdescription}--$_->{reportid}\n| }
 
+    $reportform = qq|
+      <tr>
+        <th align=right>|.$locale->text('Report').qq|</th>
+	<td>
+	  <select name=report onChange="ChangeReport();">|.$form->select_option($form->{selectreportform}, undef, 1)
+	  .qq|</select>
+	</td>
+      </tr>
+|;
+  }
 
+  for (qw(transdate reference description debit credit accno)) { $form->{"l_$_"} = "checked" }
+
+  @checked = qw(l_subtotal);
+  @input = qw(reference description name vcnumber lineitem notes source memo datefrom dateto month year accnofrom accnoto amountfrom amountto sort direction reportlogin);
+  for (qw(department)) {
+    push @input, $_ if exists $form->{$_};
+  }
+  %radio = ( interval => { 0 => 0, 1 => 1, 3 => 2, 12 => 3 },
+             category => { X => 0, A => 1, L => 2, Q => 3, I => 4, E => 5 }
+           );
+
+  $i = 1;
+  $includeinreport{id} = { ndx => $i++, sort => id, checkbox => 1, html => qq|<input name="l_id" class=checkbox type=checkbox value=Y $form->{l_id}>|, label => $locale->text('ID') };
+  $includeinreport{transdate} = { ndx => $i++, sort => transdate, checkbox => 1, html => qq|<input name="l_transdate" class=checkbox type=checkbox value=Y $form->{l_transdate}>|, label => $locale->text('Date') };
+  $includeinreport{reference} = { ndx => $i++, sort => reference, checkbox => 1, html => qq|<input name="l_reference" class=checkbox type=checkbox value=Y $form->{l_reference}>|, label => $locale->text('Reference') };
+  $includeinreport{description} = { ndx => $i++, sort => description, checkbox => 1, html => qq|<input name="l_description" class=checkbox type=checkbox value=Y $form->{l_description}>|, label => $locale->text('Description') };
+  $includeinreport{name} = { ndx => $i++, sort => name, checkbox => 1, html => qq|<input name="l_name" class=checkbox type=checkbox value=Y $form->{l_name}>|, label => $locale->text('Company Name') };
+  $includeinreport{vcnumber} = { ndx => $i++, sort => vcnumber, checkbox => 1, html => qq|<input name="l_vcnumber" class=checkbox type=checkbox value=Y $form->{l_vcnumber}>|, label => $locale->text('Company Number') };
+  $includeinreport{address} = { ndx => $i++, checkbox => 1, html => qq|<input name="l_address" class=checkbox type=checkbox value=Y $form->{l_address}>|, label => $locale->text('Address') };
+  $includeinreport{department} = { ndx => $i++, sort => department, checkbox => 1, html => qq|<input name="l_department" class=checkbox type=checkbox value=Y $form->{l_department}>|, label => $locale->text('Department') } if $l_department;
+  $includeinreport{notes} = { ndx => $i++, checkbox => 1, html => qq|<input name="l_notes" class=checkbox type=checkbox value=Y $form->{l_notes}>|, label => $locale->text('Notes') };
+  $includeinreport{debit} = { ndx => $i++, checkbox => 1, html => qq|<input name="l_debit" class=checkbox type=checkbox value=Y $form->{l_debit}>|, label => $locale->text('Debit') };
+  $includeinreport{credit} = { ndx => $i++, checkbox => 1, html => qq|<input name="l_credit" class=checkbox type=checkbox value=Y $form->{l_credit}>|, label => $locale->text('Credit') };
+  $includeinreport{source} = { ndx => $i++, sort => source, checkbox => 1, html => qq|<input name="l_source" class=checkbox type=checkbox value=Y $form->{l_source}>|, label => $locale->text('Source') };
+  $includeinreport{memo} = { ndx => $i++, sort => memo, checkbox => 1, html => qq|<input name="l_memo" class=checkbox type=checkbox value=Y $form->{l_memo}>|, label => $locale->text('Memo') };
+  $includeinreport{lineitem} = { ndx => $i++, sort => lineitem, checkbox => 1, html => qq|<input name="l_lineitem" class=checkbox type=checkbox value=Y $form->{l_lineitem}>|, label => $locale->text('Line Item') };
+  $includeinreport{accno} = { ndx => $i++, sort => accno, checkbox => 1, html => qq|<input name="l_accno" class=checkbox type=checkbox value=Y $form->{l_accno}>|, label => $locale->text('Account') };
+  $includeinreport{gifi_accno} = { ndx => $i++, sort => gifi_accno, checkbox => 1, html => qq|<input name="l_gifi_accno" class=checkbox type=checkbox value=Y $form->{l_gifi_accno}>|, label => $locale->text('GIFI') };
+  $includeinreport{contra} = { ndx => $i++, checkbox => 1, html => qq|<input name="l_contra" class=checkbox type=checkbox value=Y $form->{l_contra}>|, label => $locale->text('Contra') };
+
+  @f = ();
+  $form->{flds} = "";
+  
+  for (sort { $includeinreport{$a}->{ndx} <=> $includeinreport{$b}->{ndx} } keys %includeinreport) {
+    $form->{flds} .= "$_=$includeinreport{$_}->{label}=$includeinreport{$_}->{sort},";
+    push @checked, "l_$_";
+    if ($includeinreport{$_}->{checkbox}) {
+      push @f, "$includeinreport{$_}->{html} $includeinreport{$_}->{label}";
+    }
+  }
+  chop $form->{flds};
+
+  $form->helpref("search_gl_transactions", $myconfig{countrycode});
+  
   $form->header;
 
+  JS->change_report(\%$form, \@input, \@checked, \%radio);
+  
   print qq|
 <body>
 
 <form method=post action=$form->{script}>
 
-<input type=hidden name=sort value=transdate>
-
 <table width=100%>
   <tr>
-    <th class=listtop>$form->{title}</th>
+    <th class=listtop>$form->{helpref}$form->{title}</a></th>
   </tr>
   <tr height="5"></tr>
   <tr>
     <td>
       <table width=100%>
+        $reportform
 	<tr>
 	  <th align=right>|.$locale->text('Reference').qq| / |.$locale->text('Invoice Number').qq|</th>
 	  <td><input name=reference size=20></td>
@@ -336,10 +396,10 @@ sub search {
 		  <table>
 |;
 
-  while (@a) {
+  while (@f) {
     print qq|<tr>\n|;
-    for (1 .. 10) {
-      print qq|<td nowrap>|. shift @a;
+    for (1 .. 5) {
+      print qq|<td nowrap>|. shift @f;
       print qq|</td>\n|;
     }
     print qq|</tr>\n|;
@@ -347,7 +407,7 @@ sub search {
 
   print qq|
 		    <tr>
-		      <td><input name="l_subtotal" class=checkbox type=checkbox value=Y></td><td nowrap>|.$locale->text('Subtotal').qq|</td>
+		      <td nowrap><input name="l_subtotal" class=checkbox type=checkbox value=Y>&nbsp;|.$locale->text('Subtotal').qq|</td>
 		    </tr>
 		  </table>
 		</td>
@@ -362,24 +422,29 @@ sub search {
     <td><hr size=3 noshade></td>
   </tr>
 </table>
-
-<input type=hidden name=nextsub value=transactions>
-|;
-
-  $form->hide_form(qw(path login));
-  
-  print qq|
 <br>
-<input class=submit type=submit name=action value="|.$locale->text('Continue').qq|">
-</form>
 |;
 
+
+  %button = ('Continue' => { ndx => 1, key => 'C', value => $locale->text('Continue') } );
+  
+  for (sort { $button{$a}->{ndx} <=> $button{$b}->{ndx} } keys %button) { $form->print_button(\%button, $_) }
+  
+  $form->{sort} ||= "transdate";
+  $form->{direction} ||= "ASC";
+  
+  $form->{nextsub} = "transactions";
+  $form->{initreport} = 1;
+ 
+  $form->hide_form(qw(sort direction reportlogin nextsub initreport path login flds));
+ 
   if ($form->{menubar}) {
     require "$form->{path}/menu.pl";
     &menubar;
   }
 
   print qq|
+</form>
 
 </body>
 </html>
@@ -389,15 +454,21 @@ sub search {
 
 sub transactions {
 
-  $form->{sort} = "transdate" unless $form->{sort};
+  ($form->{reportdescription}, $form->{reportid}) = split /--/, $form->{report};
+  $form->{sort} ||= "transdate";
+  $form->{reportcode} = 'gl';
 
   GL->transactions(\%myconfig, \%$form);
-  
-  $href = "$form->{script}?action=transactions&direction=$form->{direction}&oldsort=$form->{oldsort}&path=$form->{path}&login=$form->{login}";
-  
+
+  $href = "$form->{script}?action=transactions";
+  for (qw(direction oldsort path login month year interval reportlogin)) { $href .= "&$_=$form->{$_}" }
+  for (qw(report flds)) { $href .= "&$_=".$form->escape($form->{$_}) }
+
   $form->sort_order();
 
-  $callback = "$form->{script}?action=transactions&direction=$form->{direction}&oldsort=$form->{oldsort}&path=$form->{path}&login=$form->{login}";
+  $callback = "$form->{script}?action=transactions";
+  for (qw(direction oldsort path login month year interval reportlogin)) { $callback .= "&$_=$form->{$_}" }
+  for (qw(report flds)) { $callback .= "&$_=".$form->escape($form->{$_}) }
   
   %acctype = ( 'A' => $locale->text('Asset'),
                'L' => $locale->text('Liability'),
@@ -499,7 +570,8 @@ sub transactions {
     $href .= "&accnofrom=$form->{accnofrom}";
     $callback .= "&accnofrom=$form->{accnofrom}";
     $option .= "\n<br>" if $option;
-    $option .= $locale->text('Account')." >= $form->{accnofrom}";
+    $option .= $locale->text('Account')." >= $form->{accnofrom} $form->{accnofrom_description}";
+    $form->{l_contra} = "";
   }
   if ($form->{accnoto}) {
     $href .= "&accnoto=$form->{accnoto}";
@@ -510,7 +582,8 @@ sub transactions {
       $option .= "\n<br>" if $option;
       $option .= $locale->text('Account')." <= ";
     }
-    $option .= "$form->{accnoto}";
+    $option .= "$form->{accnoto} $form->{accnoto_description}";
+    $form->{l_contra} = "";
   }
   if ($form->{amountfrom}) {
     $href .= "&amountfrom=$form->{amountfrom}";
@@ -530,63 +603,115 @@ sub transactions {
     $option .= $form->format_amount(\%myconfig, $form->{amountto}, $form->{precision});
   }
 
+  @columns = ();
+  for (split /,/, $form->{flds}) {
+    ($column, $label, $sort) = split /=/, $_;
+    push @columns, $column;
+    $column_data{$column} = $label;
+    $column_sort{$column} = $sort;
+  }
 
-  @columns = $form->sort_columns(qw(transdate id reference description name vcnumber address notes lineitem source memo debit credit accno gifi_accno department));
-  pop @columns if $form->{department};
-
+  push @columns, "gifi_contra";
+  $column_data{gifi_contra} = $column_data{contra};
+  
+  $columns{debit} = 1;
+  $columns{credit} = 1;
+  
+  
   if ($form->{link} =~ /_paid/) {
-    @columns = $form->sort_columns(qw(transdate id reference description name vcnumber address notes lineitem source memo cleared debit credit accno gifi_accno));
+    push @columns, "cleared";
+    $column_data{cleared} = $locale->text('R');
     $form->{l_cleared} = "Y";
   }
+  @columns = grep !/department/, @columns if $form->{department};
 
-  if ($form->{accno} || $form->{gifi_accno}) {
-    @columns = grep !/(accno|gifi_accno)/, @columns;
-    push @columns, "balance";
-    $form->{l_balance} = "Y";
+  $i = 0;
+  if ($form->{column_index}) {
+    for (split /,/, $form->{column_index}) {
+      s/=.*//;
+      push @column_index, $_;
+      $column_index{$_} = ++$i;
+      $form->{"l_$_"} = "Y";
+    }
+  } else {
+    for (@columns) {
+      if ($form->{"l_$_"} eq "Y") {
+	push @column_index, $_;
+	$column_index{$_} = ++$i;
+	$form->{column_index} .= "$_=$columns{$_},";
+      }
+    }
+    chop $form->{column_index};
   }
   
-  
-  foreach $item (@columns) {
-    if ($form->{"l_$item"} eq "Y") {
-      push @column_index, $item;
+  if ($form->{accno} || $form->{gifi_accno}) {
+    @column_index = grep !/(accno|gifi_accno|contra|gifi_contra)/, @column_index;
+    push @column_index, "balance";
+    $column_data{balance} = $locale->text('Balance');
+    for (qw(l_contra l_gifi_contra)) { delete $form->{$_} }
+  }
 
-      # add column to href and callback
-      $callback .= "&l_$item=Y";
-      $href .= "&l_$item=Y";
+  if ($form->{l_contra}) {
+    $form->{l_gifi_contra} = "Y" if $form->{l_gifi_accno};
+    $form->{l_contra} = "" if ! $form->{l_accno};
+  }
+
+  if ($form->{initreport}) {
+    if ($form->{movecolumn}) {
+      @column_index = $form->sort_column_index;
+    } else {
+      @column_index = ();
+      $form->{column_index} = "";
+      $i = 0;
+      $j = 0;
+      for (split /,/, $form->{report_column_index}) {
+	s/=.*//;
+	$j++;
+
+	if ($form->{"l_$_"}) {
+	  push @column_index, $_;
+	  $form->{column_index} .= "$_=$columns{$_},";
+	  delete $column_index{$_};
+	  $i++;
+	}
+      }
+
+      for (sort { $column_index{$a} <=> $column_index{$b} } keys %column_index) {
+	push @column_index, $_;
+      }
+
+      $form->{column_index} = "";
+      for (@column_index) { $form->{column_index} .= "$_=$columns{$_}," }
+      chop $form->{column_index};
+
+    }
+  } else {
+    if ($form->{movecolumn}) {
+      @column_index = $form->sort_column_index;
     }
   }
   
+  for (@columns) {
+    if ($form->{"l_$_"} eq "Y") {
+      # add column to href and callback
+      $callback .= "&l_$_=Y";
+      $href .= "&l_$_=Y";
+    }
+  }
+  
+
   if ($form->{l_subtotal} eq 'Y') {
     $callback .= "&l_subtotal=Y";
     $href .= "&l_subtotal=Y";
   }
+  $href .= "&column_index=".$form->escape($form->{column_index});
+  $callback .= "&column_index=".$form->escape($form->{column_index});
 
-  $callback .= "&category=$form->{category}";
   $href .= "&category=$form->{category}";
+  $callback .= "&category=$form->{category}";
 
-  $column_header{id} = "<th><a class=listheading href=$href&sort=id>".$locale->text('ID')."</a></th>";
-  $column_header{transdate} = "<th><a class=listheading href=$href&sort=transdate>".$locale->text('Date')."</a></th>";
-  $column_header{reference} = "<th><a class=listheading href=$href&sort=reference>".$locale->text('Reference')." /<br>".$locale->text('Invoice Number')."</a></th>";
-  $column_header{description} = "<th><a class=listheading href=$href&sort=description>".$locale->text('Description')."</a></th>";
-  $column_header{name} = "<th><a class=listheading href=$href&sort=name>".$locale->text('Company Name')."</a></th>";
-  $column_header{vcnumber} = "<th><a class=listheading href=$href&sort=vcnumber>".$locale->text('Company Number')."</a></th>";
-  $column_header{address} = "<th class=listheading>".$locale->text('Address')."</th>";
+  $form->helpref("list_gl_transactions", $myconfig{countrycode});
   
-  $column_header{lineitem} = "<th><a class=listheading href=$href&sort=lineitem>".$locale->text('Line Item')."</a></th>";
-  
-  $column_header{source} = "<th><a class=listheading href=$href&sort=source>".$locale->text('Source')."</a></th>";
-  $column_header{memo} = "<th><a class=listheading href=$href&sort=memo>".$locale->text('Memo')."</a></th>";
-  
-  $column_header{department} = "<th><a class=listheading href=$href&sort=department>".$locale->text('Department')."</a></th>";
-  
-  $column_header{notes} = "<th class=listheading>".$locale->text('Notes')."</th>";
-  $column_header{debit} = "<th class=listheading>".$locale->text('Debit')."</th>";
-  $column_header{credit} = "<th class=listheading>".$locale->text('Credit')."</th>";
-  $column_header{accno} = "<th><a class=listheading href=$href&sort=accno>".$locale->text('Account')."</a></th>";
-  $column_header{gifi_accno} = "<th><a class=listheading href=$href&sort=gifi_accno>".$locale->text('GIFI')."</a></th>";
-  $column_header{balance} = "<th>".$locale->text('Balance')."</th>";
-  $column_header{cleared} = qq|<th>|.$locale->text('R').qq|</th>|;
- 
   $form->header;
 
   print qq|
@@ -594,7 +719,7 @@ sub transactions {
 
 <table width=100%>
   <tr>
-    <th class=listtop>$form->{title}</th>
+    <th class=listtop>$form->{helpref}$form->{title}</a></th>
   </tr>
   <tr height="5"></tr>
   <tr>
@@ -603,15 +728,53 @@ sub transactions {
   <tr>
     <td>
       <table width=100%>
+|;
+
+  $l = $#column_index;
+
+  print qq|<tr>
+|;
+
+  if (!($form->{accno} || $form->{gifi_accno})) {
+    if ($l > 0) {
+      $revhref = $href;
+      $direction = ($form->{direction} eq 'DESC') ? "ASC" : "DESC";
+      $revhref =~ s/direction=$direction/direction=$form->{direction}/;
+     
+      print "\n<td align=center><a href=$revhref&movecolumn=$column_index[0],right><img src=$images/right.png border=0></td>";
+      for (1 .. $l - 1) {
+	print "\n<td align=center><a href=$revhref&movecolumn=$column_index[$_],left><img src=$images/left.png border=0><a href=$href&movecolumn=$column_index[$_],right><img src=$images/right.png border=0></td>";
+      }
+      print "\n<td align=center><a href=$revhref&movecolumn=$column_index[$l],left><img src=$images/left.png border=0></td>";
+    }
+  }
+
+  print qq|
+        </tr>
 	<tr class=listheading>
 |;
 
-  for (@column_index) { print "$column_header{$_}\n" }
-
-  print "
-        </tr>
-";
+  for (0 .. $l) {
+    if ($column_sort{$column_index[$_]}) {
+      $sort = "";
+      if ($form->{sort} eq $column_sort{$column_index[$_]}) {
+	if ($form->{direction} eq 'ASC') {
+	  $sort = qq|<img src=$images/up.png>&nbsp;&nbsp;&nbsp;|;
+	} else {
+	  $sort = qq|<img src=$images/down.png>&nbsp;&nbsp;&nbsp;|;
+	}
+      }
+      print qq|\n<th nowrap>$sort<a class=listheading href=$href&sort=$column_sort{$column_index[$_]}>$column_data{$column_index[$_]}</a></th>|;
+    } else {
+      print qq|\n<th nowrap class=listheading>$column_data{$column_index[$_]}</th>|;
+    }
+  }
   
+  print qq|
+        </tr>
+|;
+
+
   # add sort to callback
   $form->{callback} = "$callback&sort=$form->{sort}";
   $callback = $form->escape($form->{callback});
@@ -670,6 +833,8 @@ sub transactions {
     
     $column_data{id} = "<td>$ref->{id}</td>";
     $column_data{transdate} = "<td nowrap>$ref->{transdate}</td>";
+
+    $ref->{reference} ||= "&nbsp;";
     $column_data{reference} = "<td><a href=$ref->{module}.pl?action=edit&id=$ref->{id}&path=$form->{path}&login=$form->{login}&callback=$callback>$ref->{reference}</td>";
 
     for (qw(department name vcnumber address)) { $column_data{$_} = "<td>$ref->{$_}&nbsp;</td>" }
@@ -687,7 +852,18 @@ sub transactions {
     $column_data{credit} = "<td align=right>$ref->{credit}</td>";
     
     $column_data{accno} = "<td><a href=$href&accno=$ref->{accno}&callback=$callback>$ref->{accno}</a></td>";
+    $column_data{contra} = "<td>";
+    for (split / /, $ref->{contra}) {
+      $column_data{contra} .= qq|<a href=$href&accno=$_&callback=$callback>$_</a>&nbsp;|
+    }
+    $column_data{contra} .= "</td>";
     $column_data{gifi_accno} = "<td><a href=$href&gifi_accno=$ref->{gifi_accno}&callback=$callback>$ref->{gifi_accno}</a>&nbsp;</td>";
+    $column_data{gifi_contra} = "<td>";
+    for (split / /, $ref->{gifi_contra}) {
+      $column_data{gifi_contra} .= qq|<a href=$href&gifi_accno=$_&callback=$callback>$_</a>&nbsp;|
+    }
+    $column_data{gifi_contra} .= "</td>";
+
     $column_data{balance} = "<td align=right>".$form->format_amount(\%myconfig, $form->{balance} * $ml * $cml, $form->{precision}, 0)."</td>";
     $column_data{cleared} = ($ref->{cleared}) ? "<td>*</td>" : "<td>&nbsp;</td>";
 
@@ -718,32 +894,43 @@ sub transactions {
 
   for (@column_index) { print "$column_data{$_}\n" }
 
-  $i = 1;
-  if ($myconfig{acs} !~ /General Ledger--General Ledger/) {
-    $button{'General Ledger--Add Transaction'}{code} = qq|<input class=submit type=submit name=action value="|.$locale->text('GL Transaction').qq|"> |;
-    $button{'General Ledger--Add Transaction'}{order} = $i++;
+  
+  %button = ('General Ledger--Add Transaction' => { ndx => 1, key => 'G', value => $locale->text('GL Transaction') },
+  'AR--Add Transaction' => { ndx => 2, key => 'R', value => $locale->text('AR Transaction') },
+  'AR--Sales Invoice' => { ndx => 3, key => 'I', value => $locale->text('Sales Invoice ') },
+  'AR--Credit Invoice' => { ndx => 4, key => 'C', value => $locale->text('Credit Invoice ') },
+  'AP--Add Transaction' => { ndx => 5, key => 'P', value => $locale->text('AP Transaction') },
+  'AP--Vendor Invoice' => { ndx => 6, key => 'V', value => $locale->text('Vendor Invoice ') },
+  'AP--Vendor Invoice' => { ndx => 7, key => 'D', value => $locale->text('Debit Invoice ') },
+  'Save Report' => { ndx => 8, key => 'S', value => $locale->text('Save Report') }
+            );
+
+  if (!$form->{admin}) {
+    delete $button{'Save Report'} unless $form->{savereport};
   }
-  if ($myconfig{acs} !~ /AR--AR/) {
-    $button{'AR--Add Transaction'}{code} = qq|<input class=submit type=submit name=action value="|.$locale->text('AR Transaction').qq|"> |;
-    $button{'AR--Add Transaction'}{order} = $i++;
-    $button{'AR--Sales Invoice'}{code} = qq|<input class=submit type=submit name=action value="|.$locale->text('Sales Invoice ').qq|"> |;
-    $button{'AR--Sales Invoice'}{order} = $i++;
-    $button{'AR--Credit Invoice'}{code} = qq|<input class=submit type=submit name=action value="|.$locale->text('Credit Invoice ').qq|"> |;
-    $button{'AR--Credit Invoice'}{order} = $i++;
+    
+  if ($myconfig{acs} =~ /General Ledger--General Ledger/) {
+    delete $button{'General Ledger--Add Transaction'};
   }
-  if ($myconfig{acs} !~ /AP--AP/) {
-    $button{'AP--Add Transaction'}{code} = qq|<input class=submit type=submit name=action value="|.$locale->text('AP Transaction').qq|"> |;
-    $button{'AP--Add Transaction'}{order} = $i++;
-    $button{'AP--Vendor Invoice'}{code} = qq|<input class=submit type=submit name=action value="|.$locale->text('Vendor Invoice ').qq|"> |;
-    $button{'AP--Vendor Invoice'}{order} = $i++;
-    $button{'AP--Debit Invoice'}{code} = qq|<input class=submit type=submit name=action value="|.$locale->text('Debit Invoice ').qq|"> |;
-    $button{'AP--Debit Invoice'}{order} = $i++;
+  if ($myconfig{acs} =~ /AR--AR/) {
+    delete $button{'AR--Add Transaction'};
+    delete $button{'AR--Sales Invoice'};
+    delete $button{'AR--Credit Invoice'};
+  }
+  if ($myconfig{acs} =~ /AP--AP/) {
+    delete $button{'AP--AP Transaction'};
+    delete $button{'AP--Vendor Invoice'};
+    delete $button{'AP--Debit Invoice'};
   }
 
   foreach $item (split /;/, $myconfig{acs}) {
     delete $button{$item};
   }
-  
+
+  if ($form->{accno} || $form->{gifi_accno}) {
+    delete $button{'Save Report'};
+  }
+
   print qq|
         </tr>
       </table>
@@ -759,12 +946,15 @@ sub transactions {
 <form method=post action=$form->{script}>
 |;
 
-  $form->hide_form(qw(callback path login));
-  
-  foreach $item (sort { $a->{order} <=> $b->{order} } %button) {
-    print $item->{code};
+  if ($form->{year} && $form->{month}) {
+    for (qw(datefrom dateto)) { delete $form->{$_} }
   }
-
+  $form->hide_form(qw(department reference description name vcnumber lineitem notes source memo datefrom dateto month year accnofrom accnoto amountfrom amountto interval category l_subtotal));
+  
+  $form->hide_form(qw(callback path login report reportcode reportlogin column_index flds sort direction));
+  
+  for (sort { $button{$a}->{ndx} <=> $button{$b}->{ndx} } keys %button) { $form->print_button(\%button, $_) }
+  
   if ($form->{menubar}) {
     require "$form->{path}/menu.pl";
     &menubar;
@@ -829,18 +1019,18 @@ sub update {
   
   $form->{oldcurrency} = $form->{currency};
 
-  @a = ();
+  @f = ();
   $count = 0;
-  @flds = qw(accno debit credit projectnumber source memo cleared);
+  @flds = qw(accno debit credit projectnumber source memo cleared fx_transaction);
 
   for $i (1 .. $form->{rowcount}) {
     unless (($form->{"debit_$i"} eq "") && ($form->{"credit_$i"} eq "")) {
       for (qw(debit credit)) { $form->{"${_}_$i"} = $form->parse_amount(\%myconfig, $form->{"${_}_$i"}) }
       
-      push @a, {};
-      $j = $#a;
+      push @f, {};
+      $j = $#f;
       
-      for (@flds) { $a[$j]->{$_} = $form->{"${_}_$i"} }
+      for (@flds) { $f[$j]->{$_} = $form->{"${_}_$i"} }
       $count++;
     }
   }
@@ -848,7 +1038,7 @@ sub update {
 
   for $i (1 .. $count) {
     $j = $i - 1;
-    for (@flds) { $form->{"${_}_$i"} = $a[$j]->{$_} }
+    for (@flds) { $form->{"${_}_$i"} = $f[$j]->{$_} }
   }
 
   for $i ($count + 1 .. $form->{rowcount}) {
@@ -948,8 +1138,8 @@ sub display_rows {
     print qq|<tr valign=top>
     $accno
     $fx_transaction
-    <td><input name="debit_$i" size=12 value="$form->{"debit_$i"}" accesskey=$i></td>
-    <td><input name="credit_$i" size=12 value=$form->{"credit_$i"}></td>
+    <td><input name="debit_$i" class="inputright" size=12 value="$form->{"debit_$i"}" accesskey=$i></td>
+    <td><input name="credit_$i" class="inputright" size=12 value=$form->{"credit_$i"}></td>
     $source
     $memo
     $project
@@ -999,11 +1189,7 @@ sub form_header {
       
       $exchangerate .= qq|
       <th align=right nowrap>|.$locale->text('Exchange Rate').qq| <font color=red>*</font></th>
-      <td><input name=exchangerate size=10 value=$form->{exchangerate}></td>
-      <th align=right nowrap>|
-      .$locale->text('Buy').qq|</th><td>|.$form->format_amount(\%myconfig, $form->{fxbuy}).qq|</td>
-      <th align=right nowrap>|
-      .$locale->text('Sell').qq|</th><td>|.$form->format_amount(\%myconfig, $form->{fxsell}).qq|</td>|;
+      <td><input name=exchangerate class="inputright" size=10 value=$form->{exchangerate}></td>|;
     }
     $exchangerate .= qq|</tr></table></td></tr>|;
   }
@@ -1037,6 +1223,7 @@ sub form_header {
 |;
   }
 
+  $reference_documents = &reference_documents;
 
   $form->header;
 
@@ -1046,7 +1233,7 @@ sub form_header {
 <form method=post action=$form->{script}>
 |;
 
-  $form->hide_form(qw(id fxadj closedto locked oldtransdate oldcurrency recurring batch batchid batchnumber batchdescription defaultcurrency fxbuy fxsell precision));
+  $form->hide_form(qw(id fxadj closedto locked oldtransdate oldcurrency recurring batch batchid batchnumber batchdescription defaultcurrency precision helpref reference_rows referenceurl));
   $form->hide_form(map { "select$_" } qw(accno department currency));
   
   print qq|
@@ -1054,7 +1241,7 @@ sub form_header {
 
 <table width=100%>
   <tr>
-    <th class=listtop>$form->{title}</th>
+    <th class=listtop>$form->{helpref}$form->{title}</a></th>
   </tr>
   <tr height="5"></tr>
   <tr>
@@ -1078,6 +1265,7 @@ sub form_header {
 	  <th align=right>|.$locale->text('Notes').qq|</th>
 	  <td colspan=3>$notes</td>
 	</tr>
+	$reference_documents
       </table>
     </td>
   </tr>
@@ -1100,6 +1288,13 @@ sub form_header {
 
 sub form_footer {
 
+  $difference = $form->{totaldebit} - $form->{totalcredit};
+  if ($difference > 0) {
+    $form->{differencecredit} = $form->format_amount(\%myconfig, $difference, $form->{precision}, "&nbsp;");
+  } else {
+    $form->{differencedebit} = $form->format_amount(\%myconfig, $difference * -1, $form->{precision}, "&nbsp;");
+  }
+
   for (qw(totaldebit totalcredit)) { $form->{$_} = $form->format_amount(\%myconfig, $form->{$_}, $form->{precision}, "&nbsp;") }
 
 
@@ -1113,6 +1308,22 @@ sub form_footer {
 |;
   }
 
+  if ($difference) {
+    $difference = qq|
+        <tr>
+          <th>&nbsp;</th>
+	  $fx_transaction
+          <th align=right>$form->{differencedebit}</th>
+          <th align=right>$form->{differencecredit}</th>
+          <th>&nbsp;</th>
+          <th>&nbsp;</th>
+	  $project
+        </tr>
+|;
+  } else {
+    $difference = "";
+  }
+
   print qq|
         <tr class=listtotal>
 	  <th>&nbsp;</th>
@@ -1123,6 +1334,7 @@ sub form_footer {
 	  <th>&nbsp;</th>
 	  $project
         </tr>
+        $difference
       </table>
     </td>
   </tr>
@@ -1150,26 +1362,26 @@ sub form_footer {
 	       'Delete' => { ndx => 11, key => 'D', value => $locale->text('Delete') },
 	      );
     
-    %a = ();
+    %f = ();
     
     if ($form->{id}) {
-      for ('Update', 'Post as new', 'Schedule', 'New Number') { $a{$_} = 1 }
+      for ('Update', 'Post as new', 'Schedule', 'New Number') { $f{$_} = 1 }
       
       if (! $form->{locked}) {
 	if ($transdate > $form->{closedto}) {
-	  for ('Post', 'Delete') { $a{$_} = 1 }
+	  for ('Post', 'Delete') { $f{$_} = 1 }
 	}
       }
       
     } else {
       if ($transdate > $form->{closedto}) {
-	for ("Update", "Post", "Schedule", "New Number") { $a{$_} = 1 }
+	for ("Update", "Post", "Schedule", "New Number") { $f{$_} = 1 }
       }
     }
 
-    $a{'Schedule'} = 0 if $form->{batch};
+    $f{'Schedule'} = 0 if $form->{batch};
     
-    for (keys %button) { delete $button{$_} if ! $a{$_} }
+    for (keys %button) { delete $button{$_} if ! $f{$_} }
     for (sort { $button{$a}->{ndx} <=> $button{$b}->{ndx} } keys %button) { $form->print_button(\%button, $_) }
     
   }
