@@ -450,13 +450,15 @@ sub prepare_employee {
 
       while (@member) {
 	$_ = shift @member;
-	next if ! /\[$form->{employeelogin}(\@|\])??/;
+	next if ! /\[$form->{employeelogin}\@$myconfig{dbname}\]/;
 	do {
-	  if (/password/) {
+          if (/^tan=/) {
+            chomp;
+            ($null, $form->{tan}) = split /=/, $_, 2;
+          }
+	  if (/^password=/) {
             chomp;
 	    ($null, $form->{employeepassword}) = split /=/, $_, 2;
-	    $form->{oldemployeepassword} = $form->{employeepassword};
-	    last;
 	  }
 	  $_ = shift @member;
 	} until /^\s/;
@@ -533,12 +535,14 @@ sub employee_header {
 <form method=post action=$form->{script}>
 |;
 
-  $form->hide_form(qw(acs payrate_rows wage_rows deduction_rows reference_rows referenceurl status title helpref oldemployeelogin oldemployeepassword company));
+  $form->hide_form(qw(acs payrate_rows wage_rows deduction_rows reference_rows referenceurl status title helpref oldemployeelogin company));
   $form->hide_form(map { "select$_" } qw(paymentmethod payment ap wage deduction acsrole));
   
+  $login = "";
+
   if ($form->{admin}) {
     $sales = ($form->{sales}) ? "checked" : "";
-    $login = "";
+    $tan = ($form->{tan}) ? "checked" : "";
     
     if ($form->{selectacsrole}) {
       $login = qq|
@@ -560,13 +564,16 @@ sub employee_header {
 		<th align=right nowrap>|.$locale->text('Password').qq|</th>
 		<td><input name=employeepassword size=20 value="$form->{employeepassword}"></td>
 	      </tr>
+	      <tr>
+		<th align=right>|.$locale->text('E-mail TAN').qq|</th>
+		<td><input name=tan class=checkbox type=checkbox value=1 $tan></td>
+	      </tr>
 	      <tr>
 		<th align=right>|.$locale->text('Sales').qq|</th>
 		<td><input name=sales class=checkbox type=checkbox value=1 $sales></td>
 	      </tr>
 |;
   } else {
-    $sales = ($form->{sales}) ? "x" : "";
     ($acsrole) = split /--/, $form->{acsrole};
     if ($form->{selectacsrole}) {
       $login = qq|
@@ -576,18 +583,33 @@ sub employee_header {
 	      </tr>
 |;
     }
-    $login .= qq|
+
+    if ($form->{employeelogin}) {
+      $login .= qq|
 	      <tr>
 		<th align=right nowrap>|.$locale->text('Login').qq|</th>
 		<td>$form->{employeelogin}</td>
 	      </tr>
+|;
+    }
+    if ($form->{tan}) {
+      $login .= qq|
 	      <tr>
-		<th align=right>|.$locale->text('Sales').qq|</th>
-		<td>$sales</td>
+		<th align=right nowrap>|.$locale->text('Use TAN').qq|</th>
+		<td>x</td>
 	      </tr>
 |;
+    }
+    if ($form->{sales}) {
+      $login .= qq|
+	      <tr>
+		<th align=right>|.$locale->text('Sales').qq|</th>
+		<td>x</td>
+	      </tr>
+|;
+    }
 
-    $form->hide_form(qw(acsrole employeelogin sales employeepassword));
+    $form->hide_form(qw(acsrole employeelogin sales tan employeepassword));
   }
 
   print qq|
@@ -1120,30 +1142,36 @@ sub save_memberfile {
   }
 
   if ($form->{employeelogin}) {
-    $employeelogin = $form->{employeelogin};
-    $employeelogin .= "\@$myconfig{dbname}";  # new format
+    $employeelogin = "$form->{employeelogin}\@$myconfig{dbname}";
     
     # assign values from old entries
-    $oldlogin = $form->{oldemployeelogin};
-    $oldlogin .= "\@$myconfig{dbname}";
+    $oldlogin = "$form->{oldemployeelogin}\@$myconfig{dbname}";
 
     srand( time() ^ ($$ + ($$ << 15)) );
     
     if (@{ $member{$oldlogin} }) {
-      @memberlogin = grep !/password=/, @{ $member{$oldlogin} };
+      @memberlogin = grep !/^(name=|email=|password=|tan=)/, @{ $member{$oldlogin} };
+      ($oldemployeepassword) = grep /^password=/, @{ $member{$oldlogin} };
       pop @memberlogin;
 
-      if ($form->{employeepassword} ne $form->{oldemployeepassword}) {
+      $oldemployeepassword =~ s/password=//;
+      chomp $oldemployeepassword;
+
+      $form->{employeepassword} = $oldemployeepassword if $form->{nochange};
+
+      if ($form->{employeepassword} ne $oldemployeepassword) {
 	if ($form->{employeepassword}) {
 	  $password = crypt $form->{employeepassword}, substr($form->{employeelogin}, 0, 2);
 	  push @memberlogin, "password=$password\n";
 	}
       } else {
-	if ($form->{oldemployeepassword}) {
-	  push @memberlogin, "password=$form->{oldemployeepassword}\n";
+	if ($oldemployeepassword) {
+	  push @memberlogin, "password=$oldemployeepassword\n";
 	}
       }
-      
+
+      for (qw(name email tan)) { push @memberlogin, "$_=$form->{$_}\n" if $form->{$_} }
+
       @{ $member{$employeelogin} } = ();
       
       for (@memberlogin) {
@@ -1151,9 +1179,9 @@ sub save_memberfile {
       }
       
     } else {
-      for (qw(company dateformat dbconnect dbdriver dbname dbhost dboptions dbpasswd dbuser numberformat)) {
-	$m{$_} = $myconfig{$_};
-      }
+      for (qw(company dateformat dbconnect dbdriver dbname dbhost dboptions dbpasswd dbuser numberformat)) { $m{$_} = $myconfig{$_} }
+      for (qw(name email tan)) { $m{$_} = $form->{$_} }
+
       $m{dbpasswd} = pack 'u', $myconfig{dbpasswd};
       chop $m{dbpasswd};
       $m{stylesheet} = 'sql-ledger.css';
@@ -1338,6 +1366,8 @@ sub prepare_payroll {
     for (@{ $form->{all_employee} }) { $form->{selectemployee} .= qq|$_->{name}--$_->{id}\n| }
   }
 
+  $form->{locked} = ($form->{revtrans}) ? '1' : ($form->datetonum(\%myconfig, $form->{transdate}) <= $form->{closedto});
+
   if (! $form->{readonly}) {
     $form->{readonly} = 1 if $myconfig{acs} =~ /Payroll--Add Transaction/;
   }
@@ -1589,7 +1619,9 @@ sub payroll_header {
 
 sub payroll_footer {
 
-  $form->hide_form(qw(oldemployee db path login callback));
+  $form->hide_form(qw(closedto oldemployee db path login callback));
+
+  $transdate = $form->datetonum(\%myconfig, $form->{transdate});
   
   if ($form->{readonly}) {
 
@@ -1615,6 +1647,14 @@ sub payroll_footer {
       for ('Delete', 'Post as new', 'Print and Post as new') { delete $button{$_} }
     }
 
+    if ($form->{locked} || $transdate <= $form->{closedto}) {
+      for ("Preview", "Print", "Post", "Print and Post", "Delete") { delete $button{$_} }
+    }
+
+    if (!$latex) {
+      for ("Preview", "Print and Post", "Print and Post as new") { delete $button{$_} }
+    }
+
     for (sort { $button{$a}->{ndx} <=> $button{$b}->{ndx} } keys %button) { $form->print_button(\%button, $_) }
     
   }
@@ -1641,11 +1681,13 @@ sub update_payroll {
   $ap = $form->{ap};
   $pa = $form->{payment};
   $pm = $form->{paymentmethod};
-  $id = $form->{id};
-  
+  $form->{trans_id} = $id = $form->{id};
+
   ($employee, $form->{id}) = split /--/, $form->{employee};
   HR->get_employee(\%myconfig, \%$form, 1);
-  
+
+  $form->{locked} = ($form->{revtrans}) ? '1' : ($form->datetonum(\%myconfig, $form->{transdate}) <= $form->{closedto});
+
   $form->{oldemployee} = $form->{employee};
   $form->{id} = $id;
 
@@ -1720,27 +1762,26 @@ sub update_payroll {
 	  if (($ref->{trans_id} == $ed->{id}) && $ok) {
             $fromwithholding = 0;
             $fromincome = 0;
+            $form->{"deduct_$i"} = $ref->{amount};
 
-            if ($#{$form->{deduct}{$ref->{trans_id}}}) {
-	      $j = 0;
-	      for (@{ $form->{deduct}{$ref->{trans_id}} }) {
-		if ($form->{deduct}{$ed->{id}}[$j]{trans_id} == $ref->{trans_id}) {
-		  $form->{deduct}{$ed->{id}}[$j]{percent} ||= 1;
-		  if ($form->{deduct}{$ed->{id}}[$j]{withholding}) {
-		    $fromwithholding += $temp{$form->{deduct}{$ed->{id}}[$j]{id}} * $form->{deduct}{$ed->{id}}[$j]{percent};
-		  } else {
-		    $fromincome += $temp{$form->{deduct}{$ed->{id}}[$j]{id}} * $form->{deduct}{$ed->{id}}[$j]{percent};
-		  }
-		}
-		$j++;
-	      }
-	    }
+            $j = 0;
+            for (@{ $form->{deduct}{$ref->{trans_id}} }) {
+              if ($form->{deduct}{$ed->{id}}[$j]{trans_id} == $ref->{trans_id}) {
+                $form->{deduct}{$ed->{id}}[$j]{percent} ||= 1;
+                if ($form->{deduct}{$ed->{id}}[$j]{withholding}) {
+                  $fromwithholding += $temp{$form->{deduct}{$ed->{id}}[$j]{id}} * $form->{deduct}{$ed->{id}}[$j]{percent};
+                } else {
+                  $fromincome += $temp{$form->{deduct}{$ed->{id}}[$j]{id}} * $form->{deduct}{$ed->{id}}[$j]{percent};
+                }
+              }
+              $j++;
+            }
 
-	    if ($form->{payrolldeduction}{$ed->{id}}{basedon}) {
-	      $amount = $temp{$form->{payrolldeduction}{$ed->{id}}{basedon}} - $fromincome;
-	    } else {
-	      $amount = $temp{gross} - $fromincome;
-	    }
+            if ($form->{payrolldeduction}{$ed->{id}}{basedon}) {
+              $amount = $temp{$form->{payrolldeduction}{$ed->{id}}{basedon}} - $fromincome;
+            } else {
+              $amount = $temp{gross} - $fromincome;
+            }
 
 	    if (($amount * $form->{payperiod}) > $ref->{above}) {
 	      if (($amount * $form->{payperiod}) < $ref->{below}) {
@@ -1825,14 +1866,19 @@ sub post {
 
   $form->error($locale->text('Employee missing!')) unless $employee_id;
   $form->isblank("transdate", $locale->text('Date missing!'));
+
+  $transdate = $form->datetonum(\%myconfig, $form->{transdate});
+  $form->error($locale->text('Cannot post transaction for a closed period!')) if ($transdate <= $form->{closedto});
   
   if (! $form->{repost}) {
     if ($form->{id}) {
       &repost;
       exit;
+    } else {
+      delete $form->{invnumber};
     }
   }
-    
+
   if (HR->post_transaction(\%myconfig, \%$form)) {
     $form->redirect($locale->text('Transaction posted!'));
   }
