@@ -12,6 +12,7 @@
 #======================================================================
 
 use SL::RC;
+use SL::JS;
 
 1;
 # end of main
@@ -61,17 +62,17 @@ sub reconciliation {
 
   if (@{ $form->{all_years} }) {
     # accounting years
-    $selectaccountingyear = "<option>\n";
-    for (@{ $form->{all_years} }) { $selectaccountingyear .= qq|<option>$_\n| }
-    $selectaccountingmonth = "<option>\n";
-    for (sort keys %{ $form->{all_month} }) { $selectaccountingmonth .= qq|<option value=$_>|.$locale->text($form->{all_month}{$_}).qq|\n| }
+    $selectaccountingyear = "\n";
+    for (@{ $form->{all_years} }) { $selectaccountingyear .= qq|$_\n| }
+    $selectaccountingmonth = "\n";
+    for (sort keys %{ $form->{all_month} }) { $selectaccountingmonth .= qq|$_--| . $locale->text($form->{all_month}{$_}).qq|\n| }
 
     $selectfrom = qq|
         <tr>
 	  <th align=right>|.$locale->text('Period').qq|</th>
 	  <td colspan=3>
-	  <select name=month>$selectaccountingmonth</select>
-	  <select name=year>$selectaccountingyear</select>
+	  <select name=month>|.$form->select_option($selectaccountingmonth, $form->{month}, 1, 1).qq|</select>
+	  <select name=year>|.$form->select_option($selectaccountingyear, $form->{year}).qq|</select>
 	  <input name=interval class=radio type=radio value=0>&nbsp;|.$locale->text('Current').qq|
 	  <input name=interval class=radio type=radio value=1 checked>&nbsp;|.$locale->text('Month').qq|
 	  <input name=interval class=radio type=radio value=3>&nbsp;|.$locale->text('Quarter').qq|
@@ -82,6 +83,8 @@ sub reconciliation {
   }
 
 
+  $form->helpref("reconciliation", $myconfig{countrycode});
+  
   $form->header;
 
   print qq|
@@ -91,7 +94,7 @@ sub reconciliation {
 
 <table width=100%>
   <tr>
-    <th class=listtop>$form->{title}</th>
+    <th class=listtop>$form->{helpref}$form->{title}</a></th>
   </tr>
   <tr height="5"></tr>
   <tr>
@@ -201,35 +204,20 @@ sub display_form {
 
   $form->{title} = "$form->{accno}--$form->{account} / $form->{company}";
   
+  $form->helpref("rec_list", $myconfig{countrycode});
+  
   $form->header;
 
-  print qq|
-<script language="JavaScript">
-<!--
+  JS->check_all(qw(allbox checked_));
 
-function CheckAll() {
-
-  var frm = document.forms[0]
-  var el = frm.elements
-  var re = /checked_/;
-
-  for (i = 0; i < el.length; i++) {
-    if (el[i].type == 'checkbox' && re.test(el[i].name)) {
-      el[i].checked = frm.allbox.checked
-    }
-  }
-
-}
-// -->
-</script>
-  
+  print qq| 
 <body>
 
 <form method=post action=$form->{script}>
 
 <table width=100%>
   <tr>
-    <th class=listtop>$form->{title}</th>
+    <th class=listtop>$form->{helpref}$form->{title}</a></th>
   </tr>
   <tr height="5"></tr>
   <tr>
@@ -426,13 +414,13 @@ function CheckAll() {
 	      <tr>
 		<th align=right nowrap>|.$locale->text('Statement Balance').qq|</th>
 		<td width=10%></td>
-		<td align=right><input name=statementbalance size=11 value=$form->{statementbalance}></td>
+		<td align=right><input name=statementbalance class="inputright" size=11 value=$form->{statementbalance}></td>
 	      </tr>
 
 	      <tr>
 		<th align=right nowrap>|.$locale->text('Difference').qq|</th>
 		<td width=10%></td>
-		<td align=right><input name=null size=11 value=$difference></td>
+		<td align=right><input name=null class="inputright" size=11 value=$difference></td>
 		<input type=hidden name=difference value=$difference>
 	      </tr>
 	    </table>
@@ -505,6 +493,7 @@ sub select_all {
   }
 
   $form->{deselect} = 1;
+  $form->{allbox} = 1;
 
   &display_form;
   
@@ -517,6 +506,8 @@ sub deselect_all {
 
   for (@{ $form->{PR} }) { $_->{cleared} = "" }
 
+  $form->{allbox} = 0;
+
   &display_form;
   
 }
